Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-02-16 05:52:12 +0300
committerCampbell Barton <ideasman42@gmail.com>2011-02-16 05:52:12 +0300
commit5b86f5a4077fb3fb24b08c72dff8d6f9be95a15d (patch)
tree959401deea4862b066c946b5dfd1df8301046dde /modules
parentd890d19a9ee4771e057a475a98b7a11013c58133 (diff)
update for changes in blender.
Diffstat (limited to 'modules')
-rw-r--r--modules/extensions_framework/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/extensions_framework/__init__.py b/modules/extensions_framework/__init__.py
index a24f4ba5..e61b645c 100644
--- a/modules/extensions_framework/__init__.py
+++ b/modules/extensions_framework/__init__.py
@@ -115,7 +115,7 @@ def init_properties(obj, props, cache=True):
# Silently skip invalid entries in props
continue
-class declarative_property_group(bpy.types.IDPropertyGroup):
+class declarative_property_group(bpy.types.PropertyGroup):
"""A declarative_property_group describes a set of logically
related properties, using a declarative style to list each
property type, name, values, and other relevant information.
@@ -137,7 +137,7 @@ class declarative_property_group(bpy.types.IDPropertyGroup):
ef_initialised = False
"""This property tells extensions_framework which bpy.type(s)
to attach this IDPropertyGroup to. If left as an empty list,
it will not be attached to any type, but its properties will
still be initialised. The type(s) given in the list should be
a string, such as 'Scene'.
@@ -137,7 +137,7 @@ class declarative_property_group(bpy.types.IDPropertyGroup):
ef_initialised = False
"""This property tells extensions_framework which bpy.type(s)
- to attach this IDPropertyGroup to. If left as an empty list,
+ to attach this PropertyGroup to. If left as an empty list,
it will not be attached to any type, but its properties will
still be initialised. The type(s) given in the list should be